aboutsummaryrefslogtreecommitdiff
path: root/pw_build/selects.bzl
diff options
context:
space:
mode:
Diffstat (limited to 'pw_build/selects.bzl')
-rw-r--r--pw_build/selects.bzl7
1 files changed, 5 insertions, 2 deletions
diff --git a/pw_build/selects.bzl b/pw_build/selects.bzl
index 236b24a11..59a9d0a75 100644
--- a/pw_build/selects.bzl
+++ b/pw_build/selects.bzl
@@ -16,8 +16,8 @@
_RTOS_NONE = "//pw_build/constraints/rtos:none"
# Common select for tagging a target as only compatible with host OS's. This
# select implements the logic '(Windows or Macos or Linux) and not RTOS'.
# Example usage:
# load("//pw_build:selects.bzl","TARGET_COMPATIBLE_WITH_HOST_SELECT")
# pw_cc_library(
# name = "some_host_only_lib",
@@ -27,6 +27,9 @@ _RTOS_NONE = "//pw_build/constraints/rtos:none"
TARGET_COMPATIBLE_WITH_HOST_SELECT = {
"@platforms//os:windows": [_RTOS_NONE],
"@platforms//os:macos": [_RTOS_NONE],
+ "@platforms//os:ios": [_RTOS_NONE],
"@platforms//os:linux": [_RTOS_NONE],
+ "@platforms//os:chromiumos": [_RTOS_NONE],
+ "@platforms//os:android": [_RTOS_NONE],
"//conditions:default": ["@platforms//:incompatible"],
}
@@ -16,8 +16,8 @@
_RTOS_NONE = "//pw_build/constraints/rtos:none"
# Common select for tagging a target as only compatible with host OS's. This
-# select implements the logic '(Windows or Macos or Linux) and not RTOS'.
-# Example usage:
+# select implements the logic '(Windows, macOS, iOS, Linux, Android, or
+# Chromium OS) and not RTOS'. Example usage:
# load("//pw_build:selects.bzl","TARGET_COMPATIBLE_WITH_HOST_SELECT")
# pw_cc_library(